@@ -1,20 +1,8 @@
 /*
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-    Copyright (c) 2010 Andras Mantia <andras@kdab.com>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
+    SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "emptytrashcommand.h"
@@ -76,14 +64,13 @@ void EmptyTrashCommand::execute()
                 if (type.status() == Akonadi::AgentInstance::Broken) {
                     continue;
                 }
-                OrgKdeAkonadiImapSettingsInterface *iface = Util::createImapSettingsInterface(type.identifier());
+                QScopedPointer<OrgKdeAkonadiImapSettingsInterface> iface{Util::createImapSettingsInterface(type.identifier())};
                 if (iface->isValid()) {
                     const int trashImap = iface->trashCollection();
                     if (trashImap != trash.id()) {
                         trashFolder << Akonadi::Collection(trashImap);
                     }
                 }
-                delete iface;
             }
         }
         mNumberOfTrashToEmpty = trashFolder.count();
@@ -103,44 +90,21 @@ void EmptyTrashCommand::execute()
 void EmptyTrashCommand::expunge(const Akonadi::Collection &col)
 {
     if (col.isValid()) {
-        Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(col, this);
-        connect(job, &Akonadi::ItemFetchJob::result, this, &EmptyTrashCommand::slotExpungeJob);
+        Akonadi::ItemDeleteJob *jobDelete = new Akonadi::ItemDeleteJob(col, this);
+        connect(jobDelete, &Akonadi::ItemDeleteJob::result,
+                this, [this, jobDelete]() {
+                    if (jobDelete->error()) {
+                        Util::showJobError(jobDelete);
+                        emitResult(Failed);
+                    }
+                    emitResult(OK);
+                });
     } else {
-        qCDebug(AKONADIMIME_LOG) << " Try to expunge an invalid collection :" << col;
+        qCWarning(AKONADIMIME_LOG) << " Try to expunge an invalid collection :" << col;
         emitResult(Failed);
     }
 }
 
-void EmptyTrashCommand::slotExpungeJob(KJob *job)
-{
-    if (job->error()) {
-        Util::showJobError(job);
-        emitResult(Failed);
-        return;
-    }
-    Akonadi::ItemFetchJob *fjob = qobject_cast<Akonadi::ItemFetchJob *>(job);
-    if (!fjob) {
-        emitResult(Failed);
-        return;
-    }
-    const Akonadi::Item::List lstItem = fjob->items();
-    if (lstItem.isEmpty()) {
-        emitResult(OK);
-        return;
-    }
-    Akonadi::ItemDeleteJob *jobDelete = new Akonadi::ItemDeleteJob(lstItem, this);
-    connect(jobDelete, &Akonadi::ItemDeleteJob::result, this, &EmptyTrashCommand::slotDeleteJob);
-}
-
-void EmptyTrashCommand::slotDeleteJob(KJob *job)
-{
-    if (job->error()) {
-        Util::showJobError(job);
-        emitResult(Failed);
-    }
-    emitResult(OK);
-}
-
 Akonadi::AgentInstance::List EmptyTrashCommand::agentInstances()
 {
     Akonadi::AgentInstance::List relevantInstances;
@@ -181,14 +145,12 @@ bool EmptyTrashCommand::folderIsTrash(const Akonadi::Collection &col)
             continue;
         }
         if (type.identifier().contains(IMAP_RESOURCE_IDENTIFIER)) {
-            OrgKdeAkonadiImapSettingsInterface *iface = Util::createImapSettingsInterface(type.identifier());
+            QScopedPointer<OrgKdeAkonadiImapSettingsInterface> iface{Util::createImapSettingsInterface(type.identifier())};
             if (iface->isValid()) {
                 if (iface->trashCollection() == col.id()) {
-                    delete iface;
                     return true;
                 }
             }
-            delete iface;
         }
     }
     return false;
