@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+    SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_SPECIALMAILCOLLECTIONS_H
@@ -95,20 +82,20 @@ public:
      * Returns whether the given agent @p instance has a special collection of
      * the given @p type.
      */
-    bool hasCollection(Type type, const AgentInstance &instance) const;
+    Q_REQUIRED_RESULT bool hasCollection(Type type, const AgentInstance &instance) const;
 
     /**
      * Returns the special mail collection of the given @p type in the given agent
      * @p instance, or an invalid collection if such a collection is unknown.
      */
-    Akonadi::Collection collection(Type type, const AgentInstance &instance) const;
+    Q_REQUIRED_RESULT Akonadi::Collection collection(Type type, const AgentInstance &instance) const;
 
     /**
      * Returns the special collection type for a given collection, or empty if the collection
      * doesn't have a special type.
      * @since 4.11
      */
-    static Type specialCollectionType(const Akonadi::Collection &collection);
+    Q_REQUIRED_RESULT static Type specialCollectionType(const Akonadi::Collection &collection);
 
     /**
      * Registers the given @p collection as a special mail collection
@@ -133,13 +120,13 @@ public:
      * Returns whether the default resource has a special mail collection of
      * the given @p type.
      */
-    bool hasDefaultCollection(Type type) const;
+    Q_REQUIRED_RESULT bool hasDefaultCollection(Type type) const;
 
     /**
      * Returns the special mail collection of given @p type in the default
      * resource, or an invalid collection if such a collection is unknown.
      */
-    Akonadi::Collection defaultCollection(Type type) const;
+    Q_REQUIRED_RESULT Akonadi::Collection defaultCollection(Type type) const;
 
     void verifyI18nDefaultCollection(Type type);
 private Q_SLOTS:
