@@ -3,20 +3,7 @@
 
     Copyright (c) 2009 - 2010 Tobias Koenig <tokoe@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_STANDARDMAILACTIONMANAGER_H
@@ -30,7 +17,6 @@
 
 class QAction;
 class KActionCollection;
-class KJob;
 class QItemSelectionModel;
 class QWidget;
 
@@ -174,13 +160,13 @@ public:
      * Returns the list of collections that are currently selected.
      * The list is empty if no collection is currently selected.
      */
-    Akonadi::Collection::List selectedCollections() const;
+    Q_REQUIRED_RESULT Akonadi::Collection::List selectedCollections() const;
 
     /**
      * Returns the list of items that are currently selected.
      * The list is empty if no item is currently selected.
      */
-    Akonadi::Item::List selectedItems() const;
+    Q_REQUIRED_RESULT Akonadi::Item::List selectedItems() const;
 
     /**
      * Sets the favorite collections model based on which the collection
